@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2010, Phoronix Media
-	Copyright (C) 2009 - 2010, Michael Larabel
+	Copyright (C) 2009 - 2011, Phoronix Media
+	Copyright (C) 2009 - 2011, Michael Larabel
 	pts_concise_display_mode.php: The batch / concise display mode
 
 	This program is free software; you can redistribute it and/or modify
@@ -23,7 +23,7 @@
 
 class pts_concise_display_mode implements pts_display_mode_interface
 {
-	private $tab = "    ";
+	private $tab = '    ';
 
 	// Download / progress bits
 	private $progress_tab_count = 1;
@@ -39,6 +39,7 @@ class pts_concise_display_mode implements pts_display_mode_interface
 
 	// Run bits
 	private $expected_trial_run_count = 0;
+	private $trial_run_count_current = 0;
 
 	public function __construct()
 	{
@@ -49,8 +50,8 @@ class pts_concise_display_mode implements pts_display_mode_interface
 		$this->test_install_pos = 0;
 		$this->test_install_count = $test_install_manager->tests_to_install_count();
 
-		echo "\n";
-		echo $this->tab . $this->test_install_count . " Test" . ($this->test_install_count > 1 ? 's' : null) . " To Install\n";
+		echo PHP_EOL;
+		echo $this->tab . $this->test_install_count . ' Test' . ($this->test_install_count > 1 ? 's' : null) . ' To Install' . PHP_EOL;
 
 
 		$download_size = 0;
@@ -67,11 +68,11 @@ class pts_concise_display_mode implements pts_display_mode_interface
 			{
 				switch($test_file_download->get_download_location_type())
 				{
-					case "IN_DESTINATION_DIR":
+					case 'IN_DESTINATION_DIR':
 						// We don't really care about these files here since they are good to go
 						break;
-					case "LOCAL_DOWNLOAD_CACHE":
-					case "REMOTE_DOWNLOAD_CACHE":
+					case 'LOCAL_DOWNLOAD_CACHE':
+					case 'REMOTE_DOWNLOAD_CACHE':
 						$cache_size += $test_file_download->get_filesize();
 						$cache_total++;
 						break;
@@ -86,60 +87,60 @@ class pts_concise_display_mode implements pts_display_mode_interface
 
 		if($download_total > 0)
 		{
-			echo $this->tab . $this->tab . $download_total . " File" . ($download_total > 1 ? 's' : null) . " To Download";
+			echo $this->tab . $this->tab . $download_total . ' File' . ($download_total > 1 ? 's' : null) . ' To Download';
 
 			if($download_size > 0)
 			{
-				echo " [" . pts_math::set_precision($download_size / 1048576, 2) . "MB]";
+				echo ' [' . pts_math::set_precision($download_size / 1048576, 2) . 'MB]';
 			}
-			echo "\n";
+			echo PHP_EOL;
 		}
 
 		if($cache_total > 0)
 		{
-			echo $this->tab . $this->tab . $cache_total . " File" . ($cache_total > 1 ? 's' : null) . " In Cache";
+			echo $this->tab . $this->tab . $cache_total . ' File' . ($cache_total > 1 ? 's' : null) . ' In Cache';
 
 			if($cache_size > 0)
 			{
-				echo " [" . pts_math::set_precision($cache_size / 1048576, 2) . "MB]";
+				echo ' [' . pts_math::set_precision($cache_size / 1048576, 2) . 'MB]';
 			}
-			echo "\n";
+			echo PHP_EOL;
 		}
 
 		if($install_size > 0)
 		{
-			echo $this->tab . $this->tab . ceil($install_size) . "MB Of Disk Space Is Needed\n";
+			echo $this->tab . $this->tab . ceil($install_size) . 'MB Of Disk Space Is Needed' . PHP_EOL;
 		}
 
-		echo "\n";
+		echo PHP_EOL;
 	}
 	public function test_install_start($identifier)
 	{
 		$this->test_install_pos++;
-		echo $this->tab . $identifier . ":\n";
-		echo $this->tab . $this->tab . "Test Installation " . $this->test_install_pos . " of " . $this->test_install_count . "\n";
+		echo $this->tab . $identifier . ':' . PHP_EOL;
+		echo $this->tab . $this->tab . 'Test Installation ' . $this->test_install_pos . ' of ' . $this->test_install_count . PHP_EOL;
 	}
 	public function test_install_downloads($test_install_request)
 	{
 		$identifier = $test_install_request->test_profile->get_identifier();
 		$download_packages = $test_install_request->get_download_objects();
 
-		echo $this->tab . $this->tab . count($download_packages) . " File" . (isset($download_packages[1]) ? "s" : "") . " Needed";
+		echo $this->tab . $this->tab . count($download_packages) . ' File' . (isset($download_packages[1]) ? 's' : null) . ' Needed';
 
 		if(($size = $test_install_request->test_profile->get_download_size(false, 1048576)) > 0)
 		{
-			echo " [" . $size . " MB";
+			echo ' [' . $size . ' MB';
 
 			if(($avg_speed = pts_download_speed_manager::get_average_download_speed()) > 0)
 			{
 				$avg_time = ($size * 1048576) / $avg_speed;
-				echo " / " . pts_strings::format_time($avg_time, "SECONDS", true, 60);
+				echo ' / ' . pts_strings::format_time($avg_time, 'SECONDS', true, 60);
 			}
 
 			echo ']';
 		}
 
-		echo "\n";
+		echo PHP_EOL;
 	}
 	public function test_install_download_file($process, &$pts_test_file_download)
 	{
@@ -148,23 +149,23 @@ class pts_concise_display_mode implements pts_display_mode_interface
 
 		switch($process)
 		{
-			case "DOWNLOAD_FROM_CACHE":
-				$process_string = "Downloading From Cache";
-				$progress_prefix = "Downloading";
+			case 'DOWNLOAD_FROM_CACHE':
+				$process_string = 'Downloading From Cache';
+				$progress_prefix = 'Downloading';
 				break;
-			case "LINK_FROM_CACHE":
-				$process_string = "Linking From Cache";
+			case 'LINK_FROM_CACHE':
+				$process_string = 'Linking From Cache';
 				break;
-			case "COPY_FROM_CACHE":
-				$process_string = "Copying From Cache";
-				$progress_prefix = "Copying";
+			case 'COPY_FROM_CACHE':
+				$process_string = 'Copying From Cache';
+				$progress_prefix = 'Copying';
 				break;
-			case "FILE_FOUND":
-				$process_string = "File Found";
+			case 'FILE_FOUND':
+				$process_string = 'File Found';
 				break;
-			case "DOWNLOAD":
-				$process_string = "Downloading";
-				$progress_prefix = "Downloading";
+			case 'DOWNLOAD':
+				$process_string = 'Downloading';
+				$progress_prefix = 'Downloading';
 				if(($avg_speed = pts_download_speed_manager::get_average_download_speed()) > 0 && ($this_size = $pts_test_file_download->get_filesize()) > 0)
 				{
 					$expected_time = $this_size / $avg_speed;
@@ -172,11 +173,11 @@ class pts_concise_display_mode implements pts_display_mode_interface
 				break;
 		}
 
-		$expected_time = is_numeric($expected_time) && $expected_time > 0 ? pts_strings::format_time($expected_time, "SECONDS", false, 60) : null;
+		$expected_time = is_numeric($expected_time) && $expected_time > 0 ? pts_strings::format_time($expected_time, 'SECONDS', false, 60) : null;
 
 		// TODO: handle if file-name is too long for terminal width
-		$download_string = $this->tab . $this->tab . $process_string . ": " . $pts_test_file_download->get_filename();
-		$download_size_string = $pts_test_file_download->get_filesize() > 0 ? " [" . pts_math::set_precision($pts_test_file_download->get_filesize() / 1048576, 2) . "MB]" : null;
+		$download_string = $this->tab . $this->tab . $process_string . ': ' . $pts_test_file_download->get_filename();
+		$download_size_string = $pts_test_file_download->get_filesize() > 0 ? ' [' . pts_math::set_precision($pts_test_file_download->get_filesize() / 1048576, 2) . 'MB]' : null;
 		$offset_length = pts_client::terminal_width() > 1 ? pts_client::terminal_width() : pts_test_file_download::$longest_file_name_length;
 		$offset_length = $offset_length - strlen($download_string) - strlen($download_size_string) - 2;
 
@@ -185,11 +186,11 @@ class pts_concise_display_mode implements pts_display_mode_interface
 			$offset_length = 2;
 		}
 
-		$download_string .= str_repeat(" ", ($offset_length - 2));
+		$download_string .= str_repeat(' ', ($offset_length - 2));
 		$download_string .= $download_size_string;
-		echo $download_string . "\n";
+		echo $download_string . PHP_EOL;
 
-		$this->progress_line_prefix = $expected_time != null ? "Estimated Download Time: " . $expected_time : $progress_prefix;
+		$this->progress_line_prefix = $expected_time != null ? 'Estimated Download Time: ' . $expected_time : $progress_prefix;
 		$this->progress_last_float = -1;
 		$this->progress_tab_count = 2;
 		$this->progress_string_length = strlen($download_string);
@@ -224,17 +225,17 @@ class pts_concise_display_mode implements pts_display_mode_interface
 	}
 	public function test_install_progress_completed()
 	{
-		echo $this->progress_last_float != -1 ? str_repeat('.', $this->progress_char_count - $this->progress_char_pos) . "\n" : null;
+		echo $this->progress_last_float != -1 ? str_repeat('.', $this->progress_char_count - $this->progress_char_pos) . PHP_EOL : null;
 		$this->progress_last_float == -1;
 	}
 	public function test_install_begin($test_install_request)
 	{
 		if(($size = $test_install_request->test_profile->get_environment_size(false)) > 0)
 		{
-			echo $this->tab . $this->tab . "Installation Size: " . $size . " MB\n";
+			echo $this->tab . $this->tab . 'Installation Size: ' . $size . ' MB' . PHP_EOL;
 		}
 
-		echo $this->tab . $this->tab . "Installing Test" . " @ " . date("H:i:s") . "\n";
+		echo $this->tab . $this->tab . 'Installing Test' . ' @ ' . date('H:i:s') . PHP_EOL;
 		return;
 	}
 	public function test_install_output(&$to_output)
@@ -243,7 +244,7 @@ class pts_concise_display_mode implements pts_display_mode_interface
 	}
 	public function test_install_error($error_string)
 	{
-		echo $this->tab . $this->tab . $this->tab . $error_string . "\n";
+		echo $this->tab . $this->tab . $this->tab . $error_string . PHP_EOL;
 	}
 	public function test_install_prompt($prompt_string)
 	{
@@ -255,48 +256,47 @@ class pts_concise_display_mode implements pts_display_mode_interface
 	}
 	public function test_run_start(&$test_run_manager, &$test_result)
 	{
-		echo "\n\n" . $test_result->test_profile->get_title() . ":\n" . $this->tab . $test_result->test_profile->get_identifier();
+		echo PHP_EOL . PHP_EOL . $test_result->test_profile->get_title() . ':' . PHP_EOL . $this->tab . $test_result->test_profile->get_identifier();
 
 		if(($test_description = $test_result->get_arguments_description()) != false)
 		{
-			echo " [" . pts_strings::swap_variables($test_description, array("pts_client", "environmental_variables")) . "]";
+			echo ' [' . pts_client::swap_variables($test_description, array('pts_client', 'environmental_variables')) . ']';
 		}
 
-		echo "\n";
-
-		$test_run_position = pts_read_assignment("TEST_RUN_POSITION");
-		$test_run_count = pts_read_assignment("TEST_RUN_COUNT");
-		echo $this->tab . "Test Run " . $test_run_position . " of " . $test_run_count . "\n";
+		echo PHP_EOL;
+		echo $this->tab . 'Test ' . $test_run_manager->get_test_run_position() . ' of ' . $test_run_manager->get_test_run_count_reported() . PHP_EOL;
 
 		if(($remaining_length = $test_run_manager->get_estimated_run_time_remaining()) > 1)
 		{
-			echo $this->tab . "Estimated Time Remaining: " . pts_strings::format_time($remaining_length, "SECONDS", true, 60) . "\n";
+			echo $this->tab . 'Estimated Time Remaining: ' . pts_strings::format_time($remaining_length, 'SECONDS', true, 60) . PHP_EOL;
 		}
 
 		$estimated_length = $test_result->test_profile->get_estimated_run_time();
 		if($estimated_length > 1 && $estimated_length != $remaining_length)
 		{
-			echo $this->tab . "Estimated Test Run-Time: " . pts_strings::format_time($estimated_length, "SECONDS", true, 60) . "\n";
+			echo $this->tab . 'Estimated Test Run-Time: ' . pts_strings::format_time($estimated_length, 'SECONDS', true, 60) . PHP_EOL;
 		}
 
+		$this->trial_run_count_current = 0;
 		$this->expected_trial_run_count = $test_result->test_profile->get_times_to_run();
-		echo $this->tab . "Expected Trial Run Count: " . $this->expected_trial_run_count;
+		echo $this->tab . 'Expected Trial Run Count: ' . $this->expected_trial_run_count;
 	}
 	public function test_run_message($message_string)
 	{
-		echo "\n" . $this->tab . $this->tab . $message_string . " @ " . date("H:i:s");
+		echo PHP_EOL . $this->tab . $this->tab . $message_string . ' @ ' . date('H:i:s');
 	}
-	public function test_run_instance_header(&$test_result, $current_run, $total_run_count)
+	public function test_run_instance_header(&$test_result)
 	{
-		echo "\n" . $this->tab . $this->tab . "Started Run " . $current_run . " @ " . date("H:i:s");
+		$this->trial_run_count_current++;
+		echo PHP_EOL . $this->tab . $this->tab . 'Started Run ' . $this->trial_run_count_current . ' @ ' . date('H:i:s');
 	}
 	public function test_run_instance_error($error_string)
 	{
-		echo "\n" . $this->tab . $this->tab . $error_string;
+		echo PHP_EOL . $this->tab . $this->tab . $error_string;
 	}
 	public function test_run_instance_output(&$to_output)
 	{
-		if(pts_is_assignment("DEBUG_TEST_PROFILE"))
+		if((pts_c::$test_flags & pts_c::debug_mode))
 		{
 			echo $to_output;
 		}
@@ -305,48 +305,67 @@ class pts_concise_display_mode implements pts_display_mode_interface
 	}
 	public function test_run_instance_complete(&$test_result)
 	{
-		if($test_result->test_profile->get_times_to_run() > $this->expected_trial_run_count)
+		if($this->expected_trial_run_count > 1 && $this->trial_run_count_current >= $this->expected_trial_run_count)
 		{
-			// The run count must have been dynamically increased, so show the standard deviation
-			echo " [Std. Dev: " . pts_math::set_precision(pts_math::percent_standard_deviation($test_result->test_result_buffer->get_values()), 2) . "%]";
+			$values = $test_result->test_result_buffer->get_values();
+
+			if(count($values) > 1)
+			{
+				echo ($this->trial_run_count_current < 10 ? ' ' : null) . ' [Std. Dev: ' . pts_math::set_precision(pts_math::percent_standard_deviation($values), 2) . '%]';
+			}
 		}
 	}
 	public function test_run_end(&$test_result)
 	{
-		echo "\n";
+		echo PHP_EOL;
 
-		if(in_array($test_result->test_profile->get_result_format(), array("NO_RESULT", "LINE_GRAPH", "IMAGE_COMPARISON")))
+		if(in_array($test_result->test_profile->get_display_format(), array('NO_RESULT', 'IMAGE_COMPARISON')))
 		{
-			return;
+			$end_print = null;
 		}
-		else if(in_array($test_result->test_profile->get_result_format(), array("PASS_FAIL", "MULTI_PASS_FAIL")))
+		else if(in_array($test_result->test_profile->get_display_format(), array('PASS_FAIL', 'MULTI_PASS_FAIL')))
 		{
-			$end_print .= $this->tab . $this->tab . "Final: " . $test_result->get_result() . " (" . $test_result->test_profile->get_result_scale() . ")\n";
+			$end_print = $this->tab . $this->tab . 'Final: ' . $test_result->get_result() . ' (' . $test_result->test_profile->get_result_scale() . ')' . PHP_EOL;
+		}
+		else if(in_array($test_result->test_profile->get_display_format(), array('FILLED_LINE_GRAPH', 'LINE_GRAPH')))
+		{
+			$values = explode(',', $test_result->get_result());
+			$end_print = null;
+
+			if(count($values) > 1)
+			{
+				$avg = pts_math::set_precision(array_sum($values) / count($values), 2);
+				$min = pts_math::set_precision(min($values), 2);
+				$max = pts_math::set_precision(max($values), 2);
+				$end_print .= $this->tab . $this->tab . 'Average: ' . $avg . ' (' . $test_result->test_profile->get_result_scale() . ')' . PHP_EOL;
+				$end_print .= $this->tab . $this->tab . 'Minimum: ' . $min . ' (' . $test_result->test_profile->get_result_scale() . ')' . PHP_EOL;
+				$end_print .= $this->tab . $this->tab . 'Maximum: ' . $max . ' (' . $test_result->test_profile->get_result_scale() . ')' . PHP_EOL;
+			}
 		}
 		else
 		{
-			$end_print = "\n" . $this->tab . "Test Results:\n";
+			$end_print = PHP_EOL . $this->tab . 'Test Results:' . PHP_EOL;
 
 			foreach($test_result->test_result_buffer->get_values() as $result)
 			{
-				$end_print .= $this->tab . $this->tab . $result . "\n";
+				$end_print .= $this->tab . $this->tab . $result . PHP_EOL;
 			}
 
-			$end_print .= "\n" . $this->tab . pts_strings::result_format_to_string($test_result->test_profile->get_result_format()) . ": " . $test_result->get_result() . " " . $test_result->test_profile->get_result_scale();
+			$end_print .= PHP_EOL . $this->tab . pts_strings::result_quantifier_to_string($test_result->test_profile->get_result_quantifier()) . ': ' . $test_result->get_result() . ' ' . $test_result->test_profile->get_result_scale();
 
 			if($test_result->get_result() == 0)
 			{
-				$end_print .= "\n" . $this->tab . "This test failed to run properly.";
+				$end_print .= PHP_EOL . $this->tab . 'This test failed to run properly.';
 			}
 
-			$end_print .= "\n";
+			$end_print .= PHP_EOL;
 		}
 
 		echo $end_print;
 	}
 	public function test_run_error($error_string)
 	{
-		echo $this->tab . $this->tab . $error_string . "\n";
+		echo $this->tab . $this->tab . $error_string . PHP_EOL;
 	}
 	public function generic_prompt($prompt_string)
 	{
@@ -356,24 +375,24 @@ class pts_concise_display_mode implements pts_display_mode_interface
 	{
 		static $shown_pts = false;
 
-		if($shown_pts == false && pts_client::get_command_exection_count() <= 2)
+		if($shown_pts == false)
 		{
-			$string = pts_title() . "\n" . $string;
+			$string = pts_title() . PHP_EOL . $string;
 			$shown_pts = true;
 		}
 
 		if(!empty($string))
 		{
-			echo "\n";
-			foreach(pts_strings::trim_explode("\n", $string) as $line_count => $line_string)
+			echo PHP_EOL;
+			foreach(pts_strings::trim_explode(PHP_EOL, $string) as $line_count => $line_string)
 			{
 				// ($line_count > 0 ? $this->tab : null) . 
-				echo $line_string . "\n";
+				echo $line_string . PHP_EOL;
 			}
 
 			if($ending_line_break)
 			{
-				echo "\n";
+				echo PHP_EOL;
 			}
 		}
 	}
@@ -381,36 +400,36 @@ class pts_concise_display_mode implements pts_display_mode_interface
 	{
 		if(!empty($string))
 		{
-			// To generate the "Phoronix Test Suite" heading string if not already done so
+			// To generate the 'Phoronix Test Suite' heading string if not already done so
 			pts_client::$display->generic_heading(null, false);
 
-			foreach(pts_strings::trim_explode("\n", $string) as $line_string)
+			foreach(pts_strings::trim_explode(PHP_EOL, $string) as $line_string)
 			{
-				echo $this->tab . $line_string . "\n";
+				echo $this->tab . $line_string . PHP_EOL;
 			}
 		}
 	}
 	public function generic_error($string)
 	{
-		echo "\n";
-		echo "ERROR: ";
-		foreach(pts_strings::trim_explode("\n", $string) as $line_count => $line_string)
+		echo PHP_EOL;
+		echo 'ERROR: ';
+		foreach(pts_strings::trim_explode(PHP_EOL, $string) as $line_count => $line_string)
 		{
 			// ($line_count > 0 ? $this->tab : null) . 
-			echo ($line_count > 0 ? "       " : null) . $line_string . "\n";
+			echo ($line_count > 0 ? '       ' : null) . $line_string . PHP_EOL;
 		}
-		echo "\n";
+		echo PHP_EOL;
 	}
 	public function generic_warning($string)
 	{
-		echo "\n";
-		echo "WARNING: ";
-		foreach(pts_strings::trim_explode("\n", $string) as $line_count => $line_string)
+		echo PHP_EOL;
+		echo 'WARNING: ';
+		foreach(pts_strings::trim_explode(PHP_EOL, $string) as $line_count => $line_string)
 		{
 			// ($line_count > 0 ? $this->tab : null) . 
-			echo ($line_count > 0 ? "         " : null) . $line_string . "\n";
+			echo ($line_count > 0 ? '         ' : null) . $line_string . PHP_EOL;
 		}
-		echo "\n";
+		echo PHP_EOL;
 	}
 }
 
