@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2011, Phoronix Media
+	Copyright (C) 2008 - 2011, Michael Larabel
 	phodevi_monitor.php: The PTS Device Interface object for the display monitor
 
 	This program is free software; you can redistribute it and/or modify
@@ -27,17 +27,17 @@ class phodevi_monitor extends phodevi_device_interface
 	{
 		switch($identifier)
 		{
-			case "identifier":
-				$property = new phodevi_device_property("monitor_string", PHODEVI_SMART_CACHE);
+			case 'identifier':
+				$property = new phodevi_device_property('monitor_string', phodevi::smart_caching);
 				break;
-			case "count":
-				$property = new phodevi_device_property("monitor_count", PHODEVI_STAND_CACHE);
+			case 'count':
+				$property = new phodevi_device_property('monitor_count', phodevi::std_caching);
 				break;
-			case "layout":
-				$property = new phodevi_device_property("monitor_layout", PHODEVI_STAND_CACHE);
+			case 'layout':
+				$property = new phodevi_device_property('monitor_layout', phodevi::std_caching);
 				break;
-			case "modes":
-				$property = new phodevi_device_property("monitor_modes", PHODEVI_STAND_CACHE);
+			case 'modes':
+				$property = new phodevi_device_property('monitor_modes', phodevi::std_caching);
 				break;
 		}
 
@@ -45,17 +45,22 @@ class phodevi_monitor extends phodevi_device_interface
 	}
 	public static function monitor_string()
 	{
-		if(IS_MACOSX)
+		if(phodevi::is_macosx())
 		{
-			$system_profiler = shell_exec("system_profiler SPDisplaysDataType 2>&1");
-			$system_profiler = substr($system_profiler, strrpos($system_profiler, "Displays:"));
+			$system_profiler = shell_exec('system_profiler SPDisplaysDataType 2>&1');
+			$system_profiler = substr($system_profiler, strrpos($system_profiler, 'Displays:'));
 			$system_profiler = substr($system_profiler, strpos($system_profiler, "\n"));
-			$monitor = trim(substr($system_profiler, 0, strpos($system_profiler, ":")));
+			$monitor = trim(substr($system_profiler, 0, strpos($system_profiler, ':')));
+
+			if($monitor == 'Display Connector')
+			{
+				$monitor = null;
+			}
 		}
 		else
 		{
-			$log_parse = shell_exec("cat /var/log/Xorg.0.log 2>&1 | grep \"Monitor name\"");
-			$log_parse = substr($log_parse, strpos($log_parse, "Monitor name:") + 14);
+			$log_parse = shell_exec('cat /var/log/Xorg.0.log 2>&1 | grep "Monitor name"');
+			$log_parse = substr($log_parse, strpos($log_parse, 'Monitor name:') + 14);
 			$monitor = trim(substr($log_parse, 0, strpos($log_parse, "\n")));
 		}
 
@@ -72,16 +77,16 @@ class phodevi_monitor extends phodevi_device_interface
 		if($monitor_count == 0)
 		{
 			// Fallback support for ATI and NVIDIA if phodevi_parser::read_xdpy_monitor_info() fails
-			if(IS_NVIDIA_GRAPHICS)
+			if(phodevi::is_nvidia_graphics())
 			{
-				$enabled_displays = phodevi_parser::read_nvidia_extension("EnabledDisplays");
+				$enabled_displays = phodevi_parser::read_nvidia_extension('EnabledDisplays');
 
 				switch($enabled_displays)
 				{
-					case "0x00010000":
+					case '0x00010000':
 						$monitor_count = 1;
 						break;
-					case "0x00010001":
+					case '0x00010001':
 						$monitor_count = 2;
 						break;
 					default:
@@ -89,9 +94,9 @@ class phodevi_monitor extends phodevi_device_interface
 						break;
 				}
 			}
-			else if(IS_ATI_GRAPHICS && IS_LINUX)
+			else if(phodevi::is_ati_graphics() && phodevi::is_linux())
 			{
-				$amdpcsdb_enabled_monitors = phodevi_linux_parser::read_amd_pcsdb("SYSTEM/BUSID-*/DDX,EnableMonitor");
+				$amdpcsdb_enabled_monitors = phodevi_linux_parser::read_amd_pcsdb('SYSTEM/BUSID-*/DDX,EnableMonitor');
 				$amdpcsdb_enabled_monitors = pts_arrays::to_array($amdpcsdb_enabled_monitors);
 
 				foreach($amdpcsdb_enabled_monitors as $enabled_monitor)
@@ -113,56 +118,56 @@ class phodevi_monitor extends phodevi_device_interface
 	public static function monitor_layout()
 	{
 		// Determine layout for multiple monitors
-		$monitor_layout = array("CENTER");
+		$monitor_layout = array('CENTER');
 
-		if(phodevi::read_property("monitor", "count") > 1)
+		if(phodevi::read_property('monitor', 'count') > 1)
 		{
 			$xdpy_monitors = phodevi_parser::read_xdpy_monitor_info();
 			$hit_0_0 = false;
 			for($i = 0; $i < count($xdpy_monitors); $i++)
 			{
-				$monitor_position = explode("@", $xdpy_monitors[$i]);
+				$monitor_position = explode('@', $xdpy_monitors[$i]);
 				$monitor_position = trim($monitor_position[1]);
-				$monitor_position_x = substr($monitor_position, 0, strpos($monitor_position, ","));
-				$monitor_position_y = substr($monitor_position, strpos($monitor_position, ",") + 1);
+				$monitor_position_x = substr($monitor_position, 0, strpos($monitor_position, ','));
+				$monitor_position_y = substr($monitor_position, strpos($monitor_position, ',') + 1);
 
-				if($monitor_position == "0,0")
+				if($monitor_position == '0,0')
 				{
 					$hit_0_0 = true;
 				}
 				else if($monitor_position_x > 0 && $monitor_position_y == 0)
 				{
-					array_push($monitor_layout, ($hit_0_0 ? "RIGHT" : "LEFT"));
+					array_push($monitor_layout, ($hit_0_0 ? 'RIGHT' : 'LEFT'));
 				}
 				else if($monitor_position_x == 0 && $monitor_position_y > 0)
 				{
-					array_push($monitor_layout, ($hit_0_0 ? "LOWER" : "UPPER"));
+					array_push($monitor_layout, ($hit_0_0 ? 'LOWER' : 'UPPER'));
 				}
 			}
 
 			if(count($monitor_layout) == 1)
 			{
 				// Something went wrong with xdpy information, go to fallback support
-				if(IS_ATI_GRAPHICS && IS_LINUX)
+				if(phodevi::is_ati_graphics() && phodevi::is_linux())
 				{
-					$amdpcsdb_monitor_layout = phodevi_linux_parser::read_amd_pcsdb("SYSTEM/BUSID-*/DDX,DesktopSetup");
+					$amdpcsdb_monitor_layout = phodevi_linux_parser::read_amd_pcsdb('SYSTEM/BUSID-*/DDX,DesktopSetup');
 					$amdpcsdb_monitor_layout = pts_arrays::to_array($amdpcsdb_monitor_layout);
 
 					foreach($amdpcsdb_monitor_layout as $card_monitor_configuration)
 					{
 						switch($card_monitor_configuration)
 						{
-							case "horizontal":
-								array_push($monitor_layout, "RIGHT");
+							case 'horizontal':
+								array_push($monitor_layout, 'RIGHT');
 								break;
-							case "horizontal,reverse":
-								array_push($monitor_layout, "LEFT");
+							case 'horizontal,reverse':
+								array_push($monitor_layout, 'LEFT');
 								break;
-							case "vertical":
-								array_push($monitor_layout, "ABOVE");
+							case 'vertical':
+								array_push($monitor_layout, 'ABOVE');
 								break;
-							case "vertical,reverse":
-								array_push($monitor_layout, "BELOW");
+							case 'vertical,reverse':
+								array_push($monitor_layout, 'BELOW');
 								break;
 						}
 					}
@@ -170,28 +175,28 @@ class phodevi_monitor extends phodevi_device_interface
 			}
 		}
 
-		return implode(",", $monitor_layout);
+		return implode(',', $monitor_layout);
 	}
 	public static function monitor_modes()
 	{
 		// Determine resolutions for each monitor
 		$resolutions = array();
 
-		if(phodevi::read_property("monitor", "count") == 1)
+		if(phodevi::read_property('monitor', 'count') == 1)
 		{
-			array_push($resolutions, phodevi::read_property("gpu", "screen-resolution-string"));
+			array_push($resolutions, phodevi::read_property('gpu', 'screen-resolution-string'));
 		}
 		else
 		{
 			foreach(phodevi_parser::read_xdpy_monitor_info() as $monitor_line)
 			{
-				$this_resolution = substr($monitor_line, strpos($monitor_line, ":") + 2);
-				$this_resolution = substr($this_resolution, 0, strpos($this_resolution, " "));
+				$this_resolution = substr($monitor_line, strpos($monitor_line, ':') + 2);
+				$this_resolution = substr($this_resolution, 0, strpos($this_resolution, ' '));
 				array_push($resolutions, $this_resolution);
 			}
 		}
 
-		return implode(",", $resolutions);
+		return implode(',', $resolutions);
 	}
 }
 
