@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2010, Phoronix Media
-	Copyright (C) 2008 - 2010, Michael Larabel
+	Copyright (C) 2008 - 2011, Phoronix Media
+	Copyright (C) 2008 - 2011, Michael Larabel
 	pts_LineGraph.php: The line graph object that extends pts_Graph.php.
 
 	This program is free software; you can redistribute it and/or modify
@@ -24,15 +24,16 @@
 class pts_LineGraph extends pts_Graph
 {
 	protected $identifier_width = -1;
-	protected $minimum_identifier_font = 7;
+	protected $minimum_identifier_font = 6.5;
 	protected $show_select_identifiers = null;
+	public $plot_overview_text = true;
 
 	public function __construct(&$result_object, &$result_file = null)
 	{
 		parent::__construct($result_object, $result_file);
-		$this->graph_type = "LINE_GRAPH";
 		$this->graph_show_key = true;
 		$this->graph_background_lines = true;
+		$this->iveland_view = true;
 	}
 	protected function render_graph_pre_init()
 	{
@@ -46,7 +47,8 @@ class pts_LineGraph extends pts_Graph
 
 		if($this->graph_font_size_identifiers <= $this->minimum_identifier_font)
 		{
-			list($text_width, $text_height) = $this->text_string_dimensions($longest_string, $this->graph_font, $this->minimum_identifier_font + 2);
+			list($text_width, $text_height) = $this->text_string_dimensions($longest_string, $this->graph_font, $this->minimum_identifier_font + 0.5);
+			$this->graph_bottom_offset += $text_width;
 			$this->update_graph_dimensions($this->graph_attr_width, $this->graph_attr_height + $text_width);
 
 			if(($text_height + 4) > $this->identifier_width && $graph_identifiers_count > 3)
@@ -71,8 +73,6 @@ class pts_LineGraph extends pts_Graph
 		{
 			if(is_array($this->graph_identifiers[$i]))
 			{
-				// || $this->graph_identifiers[$i] == "Array"
-				// TODO: Why is "Array" text getting sent with some line graphs?
 				break;
 			}
 
@@ -126,11 +126,13 @@ class pts_LineGraph extends pts_Graph
 			for($i = 0; $i < $point_counter; $i++)
 			{
 				$value = $this->graph_data[$i_o][$i];
-				$data_string = isset($this->graph_data_title[$i_o]) ? $this->graph_data_title[$i_o] . ' @ ' . $this->graph_identifiers[$i] . ": " . $value : null;
+				$identifier = isset($this->graph_identifiers[$i]) ? $this->graph_identifiers[$i] : null;
+				$std_error = isset($this->graph_data_raw[$i_o][$i]) ? pts_math::standard_error(pts_strings::colon_explode($this->graph_data_raw[$i_o][$i])) : 0;
+				$data_string = isset($this->graph_data_title[$i_o]) ? $this->graph_data_title[$i_o] . ($identifier ? ' @ ' . $identifier : null) . ': ' . $value : null;
 
 				if($value == 0 && !$has_hit_non_zero)
 				{
-					if(defined("PHOROMATIC_TRACKER"))
+					if(defined('PHOROMATIC_TRACKER'))
 					{
 						continue;
 					}
@@ -169,11 +171,11 @@ class pts_LineGraph extends pts_Graph
 				
 				if($identifiers_empty && $i == 0)
 				{
-					array_push($poly_points, array($this->graph_left_start + 1, $value_plot_top, $data_string));
+					array_push($poly_points, array($this->graph_left_start + 1, $value_plot_top, $data_string, $std_error));
 				}
 				else if($identifiers_empty && $i == ($point_counter - 1))
 				{
-					array_push($poly_points, array($px_from_left, $value_plot_top, $data_string));
+					array_push($poly_points, array($px_from_left, $value_plot_top, $data_string, $std_error));
 					if($varying_lengths && ($point_counter * 1.1) < $point_count)
 					{
 						// This plotting ended prematurely
@@ -187,18 +189,18 @@ class pts_LineGraph extends pts_Graph
 				}
 				else
 				{
-					array_push($poly_points, array($px_from_left, $value_plot_top, $data_string));
+					array_push($poly_points, array($px_from_left, $value_plot_top, $data_string, $std_error));
 				}
 
 				if($this->regression_marker_threshold > 0 && $i > 0 && abs(1 - ($value / $prev_value)) > $this->regression_marker_threshold)
 				{
-					$regression_plots[($i - 1)] = $prev_identifier . ": " . $prev_value;
-					$regression_plots[$i] = $this->graph_identifiers[$i] . ": " . $value;
+					$regression_plots[($i - 1)] = $prev_identifier . ': ' . $prev_value;
+					$regression_plots[$i] = $identifier . ': ' . $value;
 				}
 
 				//array_push($poly_tips, array($value, $this->graph_identifiers[$i]));
 				array_push($calculations_r[$paint_color], $value);
-				$prev_identifier = $this->graph_identifiers[$i];
+				$prev_identifier = $identifier;
 				$prev_value = $value;
 			}
 
@@ -213,92 +215,109 @@ class pts_LineGraph extends pts_Graph
 					continue;
 				}
 
-				if(true || !$identifiers_empty) // TODO: determine whether to kill this check
+				$plotted_error_bar = false;
+				if($x_y_pair[3] > 0)
 				{
-					if(isset($regression_plots[$i]) && $i > 0)
+					$std_error_width = 4;
+					$std_error_rel_size = round(($x_y_pair[3] / $this->graph_maximum_value) * ($this->graph_top_end - $this->graph_top_start));
+
+					if($std_error_rel_size > 3)
 					{
-						$this->graph_image->draw_line($x_y_pair[0], $x_y_pair[1] + 6, $x_y_pair[0], $x_y_pair[1] - 6, $this->graph_color_alert, 4, $regression_plots[$i]);
+						$this->graph_image->draw_line($x_y_pair[0], $x_y_pair[1] + $std_error_rel_size, $x_y_pair[0], $x_y_pair[1] - $std_error_rel_size, $paint_color, 1);
+						$this->graph_image->draw_line($x_y_pair[0] - $std_error_width, $x_y_pair[1] - $std_error_rel_size, $x_y_pair[0] + $std_error_width, $x_y_pair[1] - $std_error_rel_size, $paint_color, 1);
+						$this->graph_image->draw_line($x_y_pair[0] - $std_error_width, $x_y_pair[1] + $std_error_rel_size, $x_y_pair[0] + $std_error_width, $x_y_pair[1] + $std_error_rel_size, $paint_color, 1);
+						$plotted_error_bar = true;
+					}
+				}
+
+				if(isset($regression_plots[$i]) && $i > 0)
+				{
+					$this->graph_image->draw_line($x_y_pair[0], $x_y_pair[1] + 6, $x_y_pair[0], $x_y_pair[1] - 6, $this->graph_color_alert, 4, $regression_plots[$i]);
+				}
+
+				$this->graph_image->draw_ellipse($x_y_pair[0], $x_y_pair[1], 7, 7, $paint_color, $paint_color, 1, !($point_counter < 6 || $plotted_error_bar || $i == 0 || $i == ($poly_points_count  - 1)), $x_y_pair[2]);
+			}
+		}
+
+		if($this->plot_overview_text)
+		{
+			$to_display = array();
+			$to_display[$this->graph_color_text] = array();
+
+			foreach(array_keys($calculations_r) as $color)
+			{
+				$to_display[$color] = array();
+			}
+
+			// in_array($this->graph_y_title, array('Percent', 'Milliwatts', 'Megabytes', 'Celsius', 'MB/s', 'Frames Per Second', 'Seconds', 'Iterations Per Minute'))
+			if(count($calculations_r) > 0)
+			{
+				array_push($to_display[$this->graph_color_text], 'Average:');
+
+				foreach($calculations_r as $color => &$values)
+				{
+					array_push($to_display[$color], array_sum($values) / count($values));
+				}
+			}
+			// in_array($this->graph_y_title, array('Megabytes', 'Milliwatts', 'Celsius', 'MB/s', 'Frames Per Second', 'Seconds', 'Iterations Per Minute'))
+			if(($this->graph_y_title != 'Percent' || $max_value < 100) && $max_value != $min_value)
+			{
+				array_push($to_display[$this->graph_color_text], 'Peak:');
+
+				foreach($calculations_r as $color => &$values)
+				{
+					array_push($to_display[$color], max($values));
+				}
+			}
+			if($min_value > 0 && $max_value != $min_value)
+			{
+				array_push($to_display[$this->graph_color_text], 'Low:');
+
+				foreach($calculations_r as $color => &$values)
+				{
+					array_push($to_display[$color], min($values));
+				}
+			}
+			/*if($point_counter > 9 && !in_array($this->graph_y_title, array('Percent')))
+			{
+				array_push($to_display[$this->graph_color_text], 'Last:');
+
+				foreach($calculations_r as $color => &$values)
+				{
+					array_push($to_display[$color], $values[count($values) - 1]);
+				}
+			}*/
+
+			// Do the actual rendering of avg / low / med high identifiers
+			$from_left = $this->graph_left_start + 6;
+
+			foreach($to_display as $color_key => &$column)
+			{
+				// removed '|| $this->graph_image->get_renderer() == 'SVG'' from line below
+				$from_top = $this->graph_top_start + 4;
+				$longest_string_width = 0;
+				$precision = max($column) > 999 ? 0 : 1;
+
+				foreach($column as &$write)
+				{
+					if(is_numeric($write))
+					{
+						$write = pts_math::set_precision($write, $precision);
 					}
 
-					$this->graph_image->draw_ellipse($x_y_pair[0], $x_y_pair[1], 7, 7, $paint_color, $paint_color, 1, !($point_counter < 6 || $i == 0 || $i == ($poly_points_count  - 1)), $x_y_pair[2]);
-				}
-			}
-		}
+					$this->graph_image->write_text_left($write, $this->graph_font, 6.5, $color_key, $from_left, $from_top, $from_left, $from_top);
+					$string_width = $this->text_string_width($write, $this->graph_font, 6.5);
 
-		$to_display = array();
-		$to_display[$this->graph_color_text] = array();
+					if($string_width > $longest_string_width)
+					{
+						$longest_string_width = $string_width;
+					}
 
-		foreach(array_keys($calculations_r) as $color)
-		{
-			$to_display[$color] = array();
-		}
-
-		// in_array($this->graph_y_title, array("Percent", "Milliwatts", "Megabytes", "Celsius", "MB/s", "Frames Per Second", "Seconds", "Iterations Per Minute"))
-		if(count($calculations_r) > 0)
-		{
-			array_push($to_display[$this->graph_color_text], "Average:");
-
-			foreach($calculations_r as $color => &$values)
-			{
-				array_push($to_display[$color], array_sum($values) / count($values));
-			}
-		}
-		// in_array($this->graph_y_title, array("Megabytes", "Milliwatts", "Celsius", "MB/s", "Frames Per Second", "Seconds", "Iterations Per Minute"))
-		if(($this->graph_y_title != "Percent" || $max_value < 100) && $max_value != $min_value)
-		{
-			array_push($to_display[$this->graph_color_text], "Peak:");
-
-			foreach($calculations_r as $color => &$values)
-			{
-				array_push($to_display[$color], max($values));
-			}
-		}
-		if($min_value > 0 && $max_value != $min_value)
-		{
-			array_push($to_display[$this->graph_color_text], "Low:");
-
-			foreach($calculations_r as $color => &$values)
-			{
-				array_push($to_display[$color], min($values));
-			}
-		}
-		/*if($point_counter > 9 && !in_array($this->graph_y_title, array("Percent")))
-		{
-			array_push($to_display[$this->graph_color_text], "Last:");
-
-			foreach($calculations_r as $color => &$values)
-			{
-				array_push($to_display[$color], $values[count($values) - 1]);
-			}
-		}*/
-
-		// Do the actual rendering of avg / low / med high identifiers
-		$from_left = $this->graph_left_start + 6;
-
-		foreach($to_display as $color_key => &$column)
-		{
-			$from_top = $this->graph_top_start + 7 + ($color_key != $this->graph_color_text || $this->graph_image->get_renderer() == "SVG" ? 1 : 0);
-			$longest_string_width = 0;
-
-			foreach($column as &$write)
-			{
-				if(is_numeric($write))
-				{
-					$write = pts_math::set_precision($write, 1);
+					$from_top += 10;
 				}
 
-				$this->graph_image->write_text_left($write, $this->graph_font, 6.5, $color_key, $from_left, $from_top, $from_left, $from_top);
-				$string_width = $this->text_string_width($write, $this->graph_font, 6.5);
-
-				if($string_width > $longest_string_width)
-				{
-					$longest_string_width = $string_width;
-				}
-
-				$from_top += 10;
+				$from_left += $longest_string_width + 3;						
 			}
-
-			$from_left += $longest_string_width + 3;						
 		}
 	}
 	protected function render_graph_result()
