@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2010, Phoronix Media
-	Copyright (C) 2008 - 2010, Michael Larabel
+	Copyright (C) 2008 - 2011, Phoronix Media
+	Copyright (C) 2008 - 2011, Michael Larabel
 	pts_module_interface.php: The generic Phoronix Test Suite module object that is extended by the specific modules/plug-ins
 
 	This program is free software; you can redistribute it and/or modify
@@ -28,26 +28,26 @@ class pts_module
 
 	public static function save_dir()
 	{
-		$prefix_dir = MODULE_DATA_DIR;
+		$prefix_dir = PTS_MODULE_DATA_PATH;
 		pts_file_io::mkdir($prefix_dir);
 
 		return $prefix_dir . str_replace("_", "-", self::module_name()) . "/";
 	}
 	public static function is_module($name)
 	{
-		return is_file(MODULE_LOCAL_DIR . $name . ".php") || is_file(MODULE_DIR . $name . ".php");
+		return is_file(PTS_MODULE_LOCAL_PATH . $name . ".php") || is_file(PTS_MODULE_PATH . $name . ".php");
 	}
 	public static function module_config_save($module_name, $set_options = null)
 	{
 		// Validate the config files, update them (or write them) if needed, and other configuration file tasks
-		pts_file_io::mkdir(MODULE_DATA_DIR . $module_name);
+		pts_file_io::mkdir(PTS_MODULE_DATA_PATH . $module_name);
 		$settings_to_write = array();
 
-		if(is_file(MODULE_DATA_DIR . $module_name . "/module-settings.xml"))
+		if(is_file(PTS_MODULE_DATA_PATH . $module_name . "/module-settings.xml"))
 		{
-			$module_config_parser = new tandem_XmlReader(MODULE_DATA_DIR . $module_name . "/module-settings.xml");
-			$option_identifier = $module_config_parser->getXMLArrayValues(P_MODULE_OPTION_IDENTIFIER);
-			$option_value = $module_config_parser->getXMLArrayValues(P_MODULE_OPTION_VALUE);
+			$module_config_parser = new nye_XmlReader(PTS_MODULE_DATA_PATH . $module_name . "/module-settings.xml");
+			$option_identifier = $module_config_parser->getXMLArrayValues('PhoronixTestSuite/ModuleSettings/Option/Identifier');
+			$option_value = $module_config_parser->getXMLArrayValues('PhoronixTestSuite/ModuleSettings/Option/Value');
 
 			for($i = 0; $i < count($option_identifier); $i++)
 			{
@@ -60,17 +60,15 @@ class pts_module
 			$settings_to_write[$identifier] = $value;
 		}
 
-		$config = new tandem_XmlWriter();
-		$i = 0;
+		$config = new nye_XmlWriter();
 
 		foreach($settings_to_write as $identifier => $value)
 		{
-			$config->addXmlObject(P_MODULE_OPTION_IDENTIFIER, $i, $identifier);
-			$config->addXmlObject(P_MODULE_OPTION_VALUE, $i, $value);
-			$i++;
+			$config->addXmlNode('PhoronixTestSuite/ModuleSettings/Option/Identifier', $identifier);
+			$config->addXmlNode('PhoronixTestSuite/ModuleSettings/Option/Value', $value);
 		}
 
-		$config->saveXMLFile(MODULE_DATA_DIR . $module_name . "/module-settings.xml");
+		$config->saveXMLFile(PTS_MODULE_DATA_PATH . $module_name . "/module-settings.xml");
 	}
 	public static function is_module_setup()
 	{
@@ -123,9 +121,9 @@ class pts_module
 		$module_name = self::module_name();
 		$value = false;
 
-		$module_config_parser = new tandem_XmlReader(MODULE_DATA_DIR . $module_name . "/module-settings.xml");
-		$option_identifier = $module_config_parser->getXMLArrayValues(P_MODULE_OPTION_IDENTIFIER);
-		$option_value = $module_config_parser->getXMLArrayValues(P_MODULE_OPTION_VALUE);
+		$module_config_parser = new nye_XmlReader(PTS_MODULE_DATA_PATH . $module_name . "/module-settings.xml");
+		$option_identifier = $module_config_parser->getXMLArrayValues('PhoronixTestSuite/ModuleSettings/Option/Identifier');
+		$option_value = $module_config_parser->getXMLArrayValues('PhoronixTestSuite/ModuleSettings/Option/Value');
 
 		for($i = 0; $i < count($option_identifier) && $value == false; $i++)
 		{
@@ -156,9 +154,9 @@ class pts_module
 		$module_name = self::module_name();
 		$options = array();
 
-		$module_config_parser = new tandem_XmlReader(MODULE_DATA_DIR . $module_name . "/module-settings.xml");
-		$option_identifier = $module_config_parser->getXMLArrayValues(P_MODULE_OPTION_IDENTIFIER);
-		$option_value = $module_config_parser->getXMLArrayValues(P_MODULE_OPTION_VALUE);
+		$module_config_parser = new nye_XmlReader(PTS_MODULE_DATA_PATH . $module_name . "/module-settings.xml");
+		$option_identifier = $module_config_parser->getXMLArrayValues('PhoronixTestSuite/ModuleSettings/Option/Identifier');
+		$option_value = $module_config_parser->getXMLArrayValues('PhoronixTestSuite/ModuleSettings/Option/Value');
 
 		for($i = 0; $i < count($option_identifier); $i++)
 		{
@@ -250,7 +248,7 @@ class pts_module
 	}
 	public static function pts_timed_function($function, $time)
 	{
-		if(($time < 3 && $time != -1) || $time > 300)
+		if(($time < 0.5 && $time != -1) || $time > 300)
 		{
 			return;
 		}
@@ -273,7 +271,7 @@ class pts_module
 					$start_id = pts_unique_runtime_identifier();
 					 && ($start_id == pts_unique_runtime_identifier() || $start_id == PTS_INIT_TIME)
 					*/
-					while(!pts_is_assignment("PTS_TESTING_DONE") && is_file(PTS_USER_LOCK) && $loop_continue)
+					while(pts_test_run_manager::test_run_process_active() !== -1 && is_file(PTS_USER_LOCK) && $loop_continue)
 					{
 						call_user_func(array(self::module_name(), $function));
 
