@@ -34,12 +34,7 @@ class pts_module_manager
 	public static function load_module($module)
 	{
 		// Load the actual file needed that contains the module
-		if(is_file(PTS_CORE_PATH . "definitions/module-" . $module . ".xml"))
-		{
-			pts_loader::load_definitions("module-" . $module . ".xml");
-		}
-
-		return (is_file(MODULE_DIR . $module . ".php") && include_once(MODULE_DIR . $module . ".php")) || (is_file(MODULE_LOCAL_DIR . $module . ".php") && include_once(MODULE_LOCAL_DIR . $module . ".php"));
+		return (is_file(PTS_MODULE_PATH . $module . ".php") && include_once(PTS_MODULE_PATH . $module . ".php")) || (is_file(PTS_MODULE_LOCAL_PATH . $module . ".php") && include_once(PTS_MODULE_LOCAL_PATH . $module . ".php"));
 	}
 	public static function module_call($module, $process, &$object_pass = null)
 	{
@@ -54,7 +49,8 @@ class pts_module_manager
 		}
 		else
 		{
-			eval("\$module_val = " . $module . "::" . $process . ";");
+			$class_vars = get_class_vars($module);
+			$module_val = isset($class_vars[$process]) ? $class_vars[$process] : false;
 		}
 
 		return $module_val;
@@ -82,16 +78,15 @@ class pts_module_manager
 		}
 		pts_module_manager::set_current_module(null);
 	}
-	public static function process_extensions_string($extensions)
+	public static function process_environment_variables_string_to_set($env_var_string)
 	{
-		// Process extensions for modules
-		if(!empty($extensions))
+		if(!empty($env_var_string))
 		{
-			foreach(explode(';', $extensions) as $ev)
+			foreach(explode(';', $env_var_string) as $ev)
 			{
 				list($var, $value) = pts_strings::trim_explode('=', $ev);
 				pts_client::set_environmental_variable($var, $value);
-				pts_module_maanager::var_store_add($var, $value);
+				pts_module_manager::var_store_add($var, $value);
 			}
 
 			pts_module_manager::detect_modules_to_load();
@@ -197,7 +192,7 @@ class pts_module_manager
 	}
 	public static function available_modules()
 	{
-		$modules = array_merge(pts_file_io::glob(MODULE_DIR . "*.php"), pts_file_io::glob(MODULE_LOCAL_DIR . "*.php"));
+		$modules = array_merge(pts_file_io::glob(PTS_MODULE_PATH . "*.php"), pts_file_io::glob(PTS_MODULE_LOCAL_PATH . "*.php"));
 		$module_names = array();
 
 		foreach($modules as $module)
@@ -225,7 +220,7 @@ class pts_module_manager
 	public static function detect_modules_to_load()
 	{
 		// Auto detect modules to load
-		foreach(explode("\n", pts_file_io::file_get_contents(STATIC_DIR . "lists/module-variables.list")) as $module_var)
+		foreach(explode("\n", pts_file_io::file_get_contents(PTS_CORE_STATIC_PATH . "lists/module-variables.list")) as $module_var)
 		{
 			$module_var = pts_strings::trim_explode("=", $module_var);
 
