@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009 - 2010, Phoronix Media
-	Copyright (C) 2009 - 2010, Michael Larabel
+	Copyright (C) 2009 - 2011, Phoronix Media
+	Copyright (C) 2009 - 2011, Michael Larabel
 	pts_storage_object.php: An object for storing other PTS objects on the disk
 
 	This program is free software; you can redistribute it and/or modify
@@ -46,6 +46,10 @@ class pts_storage_object
 	{
 		return isset($this->object_cache[$identifier]) ? $this->object_cache[$identifier] : false;
 	}
+	public function remove_object($identifier)
+	{
+		unset($this->object_cache[$identifier]);
+	}
 	public function get_objects()
 	{
 		return $this->object_cache;
@@ -76,6 +80,22 @@ class pts_storage_object
 	{
 		return $this->creation_time;
 	}
+	public function force_recover_from_file($read_from_file)
+	{
+		$restore_obj = false;
+
+		if(is_file($read_from_file))
+		{
+			$restore = unserialize(base64_decode(file_get_contents($read_from_file)));
+
+			if($restore instanceof pts_storage_object)
+			{
+				$restore_obj = $restore;
+			}
+		}
+
+		return $restore_obj;
+	}
 	public static function recover_from_file($read_from_file)
 	{
 		$restore_obj = false;
@@ -84,11 +104,11 @@ class pts_storage_object
 		{
 			$restore = unserialize(base64_decode(file_get_contents($read_from_file)));
 
-			if($restore instanceOf pts_storage_object)
+			if($restore instanceof pts_storage_object)
 			{
 				if(($restore->get_span_versions() || $restore->get_pts_version() == PTS_VERSION) && md5(serialize($restore->get_objects())) == $restore->get_object_checksum())
 				{
-					if(!$restore->get_span_reboots())
+					if($restore->get_span_reboots() == false)
 					{
 						$continue_loading = $restore->get_creation_time() > (time() - phodevi::system_uptime());
 					}
@@ -117,6 +137,16 @@ class pts_storage_object
 			$storage->save_to_file($storage_file);
 		}
 	}
+	public static function remove_in_file($storage_file, $identifier)
+	{
+		$storage = self::recover_from_file($storage_file);
+
+		if($storage != false)
+		{
+			$storage->remove_object($identifier);
+			$storage->save_to_file($storage_file);
+		}
+	}
 	public static function add_in_file($storage_file, $identifier, $add)
 	{
 		$storage = self::recover_from_file($storage_file);
