@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2009, Phoronix Media
-	Copyright (C) 2008 - 2009, Michael Larabel
+	Copyright (C) 2008 - 2011, Phoronix Media
+	Copyright (C) 2008 - 2011, Michael Larabel
 	pts_test_option: An object used for storing a test option and its possible values
 
 	This program is free software; you can redistribute it and/or modify
@@ -67,6 +67,10 @@ class pts_test_option
 	{
 		return $this->postfix;
 	}
+	public function get_option_default_raw()
+	{
+		return $this->default_entry == -1 ? 0 : $this->default_entry;
+	}
 	public function get_option_default()
 	{		
 		return $this->default_entry == -1 ? $this->option_count() - 1 : $this->default_entry;
@@ -75,6 +79,10 @@ class pts_test_option
 	{
 		array_push($this->options, array($name, $value, $message));
 	}
+	public function get_options_array()
+	{
+		return $this->options;
+	}
 	public function get_all_option_names()
 	{
 		$names = array();
@@ -94,7 +102,7 @@ class pts_test_option
 		{
 			$user_msg = $this->get_option_message($i);
 
-			array_push($names, $this->get_option_name($i) . (!empty($user_msg) ? " [" . $user_msg . ']' : null));
+			array_push($names, $this->get_option_name($i) . (!empty($user_msg) ? ' [' . $user_msg . ']' : null));
 		}
 
 		return $names;
@@ -123,7 +131,7 @@ class pts_test_option
 	{
 		$name = $this->get_name();
 
-		return $name != null && $input != null ? $name . ": " . $input : null;
+		return $name != null && $input != null ? $name . ': ' . $input : null;
 	}
 	public function format_option_value_from_select($select_pos)
 	{
@@ -135,7 +143,7 @@ class pts_test_option
 	{
 		$display_name = $this->get_option_name($select_pos);
 
-		if(($cut_point = strpos($display_name, "(")) > 1 && strpos($display_name, ")") > $cut_point)
+		if(($cut_point = strpos($display_name, '(')) > 1 && strpos($display_name, ')') > $cut_point)
 		{
 			$display_name = trim(substr($display_name, 0, $cut_point));
 		}
@@ -146,9 +154,9 @@ class pts_test_option
 	{
 		$valid = false;
 
-		if($select_pos > 0 && $select_pos <= $this->option_count())
+		if($select_pos >= 0 && $select_pos < $this->option_count())
 		{
-			$valid = $select_pos - 1;
+			$valid = $select_pos;
 		}
 		else if(in_array($select_pos, $this->get_all_option_names()))
 		{
@@ -170,20 +178,27 @@ class pts_test_option
 	{
 		$return_keys = array();
 
-		foreach(pts_strings::comma_explode($input) as $input_choice)
+		if($input === '0')
 		{
-			if($input_choice == ($this->option_count() + 1) || $input_choice == "Test All Options")
+			array_push($return_keys, 0);
+		}
+		else
+		{
+			foreach(pts_strings::comma_explode($input) as $input_choice)
 			{
-				// Add all options
-				foreach(array_keys($this->options) as $i)
+				if($input_choice == $this->option_count() || $input_choice == 'Test All Options')
 				{
-					array_push($return_keys, $i);
+					// Add all options
+					foreach(array_keys($this->options) as $i)
+					{
+						array_push($return_keys, $i);
+					}
+					break;
+				}
+				else if(($c = $this->is_valid_select_choice($input_choice)) !== false)
+				{
+					array_push($return_keys, $c);
 				}
-				break;
-			}
-			else if(($c = $this->is_valid_select_choice($input_choice)) !== false)
-			{
-				array_push($return_keys, $c);
 			}
 		}
 
