@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2009, Phoronix Media
-	Copyright (C) 2009, Michael Larabel
+	Copyright (C) 2009 - 2011, Phoronix Media
+	Copyright (C) 2009 - 2011, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -32,6 +32,14 @@ class pts_test_result_buffer_item
 		$this->result_final = $final;
 		$this->result_raw = $raw;
 	}
+	public function reset_result_value($value)
+	{
+		$this->result_final = $value;
+	}
+	public function reset_raw_value($value)
+	{
+		$this->result_raw = $value;
+	}
 	public function get_result_identifier()
 	{
 		return $this->result_identifier;
@@ -44,6 +52,22 @@ class pts_test_result_buffer_item
 	{
 		return $this->result_raw;
 	}
+	public function __toString()
+	{
+		return strtolower($this->get_result_identifier());
+	}
+	public static function compare_value($a, $b)
+	{
+		$a = $a->get_result_value();
+		$b = $b->get_result_value();
+
+		if($a == $b)
+		{
+			return 0;
+		}
+
+		return $a < $b ? -1 : 1;
+	}
 }
 
 ?>
