@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2010, Phoronix Media
-	Copyright (C) 2010, Michael Larabel
+	Copyright (C) 2010 - 2011, Phoronix Media
+	Copyright (C) 2010 - 2011, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -25,13 +25,21 @@ class pts_test_result_parser
 	private static $supported_sensors = null;
 	private static $monitoring_sensors = array();
 
-	public static function system_monitor_task_check(&$test_profile, $parse_xml_file, $test_directory)
+	public static function system_monitor_task_check(&$test_profile)
 	{
+		$parse_xml_file = $test_profile->get_file_parser_spec();
+
+		if($parse_xml_file == false)
+		{
+			return false;
+		}
+
 		self::$monitoring_sensors = array();
-		$results_parser_xml = new pts_parse_results_tandem_XmlReader($parse_xml_file);
-		$monitor_sensor = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_MONITOR_SENSOR);
-		$monitor_frequency = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_MONITOR_FREQUENCY);
-		$monitor_report_as = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_MONITOR_REPORT);
+		$test_directory = $test_profile->get_install_dir();
+		$results_parser_xml = new pts_parse_results_nye_XmlReader($parse_xml_file);
+		$monitor_sensor = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/SystemMonitor/Sensor');
+		$monitor_frequency = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/SystemMonitor/PollingFrequency');
+		$monitor_report_as = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/SystemMonitor/Report');
 
 		if(count($monitor_sensor) == 0)
 		{
@@ -39,12 +47,6 @@ class pts_test_result_parser
 			return false;
 		}
 
-		if(!function_exists("pcntl_fork"))
-		{
-			pts_client::$display->test_run_instance_error("PHP with PCNTL support enabled is required for this test.");
-			return false;
-		}
-
 		if(self::$supported_sensors == null)
 		{
 			// Cache this since this shouldn't change between tests/runs
@@ -56,7 +58,7 @@ class pts_test_result_parser
 			// TODO: Right now we are looping through SystemMonitor tags, but right now pts-core only supports providing one monitor sensor as the result
 			$sensor = explode('.', $monitor_sensor[$i]);
 
-			if($sensor == array("sys", "time"))
+			if($sensor == array('sys', 'time'))
 			{
 				// sys.time is a special case since we are just timing the test length and thus don't need to fork the thread
 				$start_time = microtime(true);
@@ -78,13 +80,19 @@ class pts_test_result_parser
 
 			$monitor_frequency[$i] *= 1000000; // Convert from seconds to micro-seconds
 
-			if(!in_array($monitor_report_as[$i], array("ALL", "MAX", "MIN", "AVG")))
+			if(!in_array($monitor_report_as[$i], array('ALL', 'MAX', 'MIN', 'AVG')))
 			{
 				// Not a valid reporting type
 				continue;
 			}
 
-			$monitor_file = tempnam($test_directory, ".monitor");
+			if(!function_exists('pcntl_fork'))
+			{
+				pts_client::$display->test_run_instance_error('PHP with PCNTL support enabled is required for this test.');
+				return false;
+			}
+
+			$monitor_file = tempnam($test_directory, '.monitor');
 			$pid = pcntl_fork();
 
 			if($pid != -1)
@@ -102,7 +110,7 @@ class pts_test_result_parser
 					while(is_file(PTS_USER_LOCK)) // TODO: or perhaps it may be okay to just do while(true) since posix_kill() is used when needed
 					{
 						array_push($sensor_values, phodevi::read_sensor($sensor));
-						file_put_contents($monitor_file, implode($sensor_values, "\n"));
+						file_put_contents($monitor_file, implode("\n", $sensor_values));
 						usleep($monitor_frequency[$i]);
 					}
 
@@ -113,11 +121,13 @@ class pts_test_result_parser
 
 		return count(self::$monitoring_sensors) > 0;
 	}
-	public static function system_monitor_task_post_test(&$test_profile, $test_directory)
+	public static function system_monitor_task_post_test(&$test_profile)
 	{
+		$test_directory = $test_profile->get_install_dir();
+
 		foreach(self::$monitoring_sensors as $sensor_r)
 		{
-			if($sensor_r[1] == array("sys", "time"))
+			if($sensor_r[1] == array('sys', 'time'))
 			{
 				// sys.time is a special case
 				$end_time = microtime(true);
@@ -134,9 +144,9 @@ class pts_test_result_parser
 			else
 			{
 				// Kill the sensor monitoring thread
-				if(function_exists("posix_kill") == false)
+				if(function_exists('posix_kill') == false)
 				{
-					pts_client::$display->test_run_error("The PHP POSIX extension is required for this test.");
+					pts_client::$display->test_run_error('The PHP POSIX extension is required for this test.');
 					return false;
 				}
 
@@ -152,16 +162,16 @@ class pts_test_result_parser
 
 				switch($sensor_r[2])
 				{
-					case "MAX":
+					case 'MAX':
 						$result_value = max($sensor_values);
 						break;
-					case "MIN":
+					case 'MIN':
 						$result_value = min($sensor_values);
 						break;
-					case "AVG":
+					case 'AVG':
 						$result_value = array_sum($sensor_values) / count($sensor_values);
 						break;
-					case "ALL":
+					case 'ALL':
 						$result_value = implode(',', $sensor_values);
 						break;
 					default:
@@ -179,19 +189,26 @@ class pts_test_result_parser
 
 		return false;
 	}
-	public static function parse_result(&$test_run_request, $parse_xml_file, $test_log_file)
+	public static function parse_result(&$test_run_request, $test_log_file)
 	{
+		$parse_xml_file = $test_run_request->test_profile->get_file_parser_spec();
+
+		if($parse_xml_file == false)
+		{
+			return null;
+		}
+
 		$test_identifier = $test_run_request->test_profile->get_identifier();
 		$extra_arguments = $test_run_request->get_arguments();
-		$pts_test_arguments = $pts_test_arguments = trim($test_run_request->test_profile->get_default_arguments() . " " . str_replace($test_run_request->test_profile->get_default_arguments(), "", $extra_arguments) . " " . $test_run_request->test_profile->get_default_post_arguments());
+		$pts_test_arguments = trim($test_run_request->test_profile->get_default_arguments() . ' ' . str_replace($test_run_request->test_profile->get_default_arguments(), '', $extra_arguments) . ' ' . $test_run_request->test_profile->get_default_post_arguments());
 
-		switch($test_run_request->test_profile->get_result_format())
+		switch($test_run_request->test_profile->get_display_format())
 		{
-			case "IMAGE_COMPARISON":
-				$test_result = self::parse_iqc_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
+			case 'IMAGE_COMPARISON':
+				$test_result = self::parse_iqc_result($test_run_request->test_profile, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
 				break;
-			case "PASS_FAIL":
-			case "MULTI_PASS_FAIL":
+			case 'PASS_FAIL':
+			case 'MULTI_PASS_FAIL':
 				$test_result = self::parse_generic_result($test_identifier, $parse_xml_file, $test_log_file, $pts_test_arguments, $extra_arguments);
 				break;
 			default:
@@ -201,7 +218,7 @@ class pts_test_result_parser
 
 		return $test_result;
 	}
-	public function calculate_end_result(&$test_result)
+	public static function calculate_end_result(&$test_result)
 	{
 		$trial_results = $test_result->test_result_buffer->get_values();
 
@@ -213,17 +230,18 @@ class pts_test_result_parser
 
 		$END_RESULT = 0;
 
-		switch($test_result->test_profile->get_result_format())
+		switch($test_result->test_profile->get_display_format())
 		{
-			case "NO_RESULT":
+			case 'NO_RESULT':
 				// Nothing to do, there are no results
 				break;
-			case "LINE_GRAPH":
-			case "TEST_COUNT_PASS":
+			case 'LINE_GRAPH':
+			case 'FILLED_LINE_GRAPH':
+			case 'TEST_COUNT_PASS':
 				// Just take the first result
 				$END_RESULT = $trial_results[0];
 				break;
-			case "IMAGE_COMPARISON":
+			case 'IMAGE_COMPARISON':
 				// Capture the image
 				$iqc_image_png = $trial_results[0];
 
@@ -234,8 +252,8 @@ class pts_test_result_parser
 					unlink($iqc_image_png);				
 				}
 				break;
-			case "PASS_FAIL":
-			case "MULTI_PASS_FAIL":
+			case 'PASS_FAIL':
+			case 'MULTI_PASS_FAIL':
 				// Calculate pass/fail type
 				$END_RESULT = -1;
 
@@ -247,34 +265,35 @@ class pts_test_result_parser
 				{
 					foreach($trial_results as $result)
 					{
-						if($result == "FALSE" || $result == "0" || $result == "FAIL")
+						if($result == 'FALSE' || $result == '0' || $result == 'FAIL')
 						{
-							if($END_RESULT == -1 || $END_RESULT == "PASS")
+							if($END_RESULT == -1 || $END_RESULT == 'PASS')
 							{
-								$END_RESULT = "FAIL";
+								$END_RESULT = 'FAIL';
 							}
 						}
 						else
 						{
 							if($END_RESULT == -1)
 							{
-								$END_RESULT = "PASS";
+								$END_RESULT = 'PASS';
 							}
 						}
 					}
 				}
 				break;
-			case "BAR_GRAPH":
+			case 'BAR_GRAPH':
 			default:
 				// Result is of a normal numerical type
 				switch($test_result->test_profile->get_result_quantifier())
 				{
-					case "MAX":
+					case 'MAX':
 						$END_RESULT = max($trial_results);
 						break;
-					case "MIN":
+					case 'MIN':
 						$END_RESULT = min($trial_results);
 						break;
+					case 'AVG':
 					default:
 						// assume AVG (average)
 						$is_float = false;
@@ -310,19 +329,19 @@ class pts_test_result_parser
 
 		$test_result->set_result($END_RESULT);
 	}
-	protected static function parse_iqc_result($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments)
+	protected static function parse_iqc_result(&$test_profile, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments)
 	{
-		$results_parser_xml = new pts_parse_results_tandem_XmlReader($parse_xml_file);
-		$result_match_test_arguments = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_MATCH_TO_TEST_ARGUMENTS);
-		$result_iqc_source_file = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_SOURCE_IMAGE);
-		$result_iqc_image_x = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_IMAGE_X);
-		$result_iqc_image_y = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_IMAGE_Y);
-		$result_iqc_image_width = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_IMAGE_WIDTH);
-		$result_iqc_image_height = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_IMAGE_HEIGHT);
+		$results_parser_xml = new pts_parse_results_nye_XmlReader($parse_xml_file);
+		$result_match_test_arguments = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ImageParser/MatchToTestArguments');
+		$result_iqc_source_file = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ImageParser/SourceImage');
+		$result_iqc_image_x = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ImageParser/ImageX');
+		$result_iqc_image_y = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ImageParser/ImageY');
+		$result_iqc_image_width = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ImageParser/ImageWidth');
+		$result_iqc_image_height = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ImageParser/ImageHeight');
 
 		$test_result = false;
 
-		if(!extension_loaded("gd"))
+		if(!extension_loaded('gd'))
 		{
 			// Needs GD library to work
 			return false;
@@ -336,9 +355,9 @@ class pts_test_result_parser
 				continue;
 			}
 
-			if(is_file(TEST_ENV_DIR . $test_identifier . '/' . $result_iqc_source_file[$i]))
+			if(is_file($test_profile->get_install_dir() . $result_iqc_source_file[$i]))
 			{
-				$iqc_source_file = TEST_ENV_DIR . $test_identifier . '/' . $result_iqc_source_file[$i];
+				$iqc_source_file = $test_profile->get_install_dir() . $result_iqc_source_file[$i];
 			}
 			else
 			{
@@ -354,7 +373,7 @@ class pts_test_result_parser
 
 			$img_sliced = imagecreatetruecolor($result_iqc_image_width[$i], $result_iqc_image_height[$i]);
 			imagecopyresampled($img_sliced, $img, 0, 0, $result_iqc_image_x[$i], $result_iqc_image_y[$i], $result_iqc_image_width[$i], $result_iqc_image_height[$i], $result_iqc_image_width[$i], $result_iqc_image_height[$i]);
-			$test_result = TEST_ENV_DIR . $test_identifier . "/iqc.png";
+			$test_result = $test_profile->get_install_dir() . 'iqc.png';
 			imagepng($img_sliced, $test_result);
 
 			if($test_result != false)
@@ -375,19 +394,19 @@ class pts_test_result_parser
 	}
 	protected static function parse_result_process($test_identifier, $parse_xml_file, $log_file, $pts_test_arguments, $extra_arguments, $is_numeric_check = true)
 	{
-		$results_parser_xml = new pts_parse_results_tandem_XmlReader($parse_xml_file);
-		$result_match_test_arguments = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_MATCH_TO_TEST_ARGUMENTS);
-		$result_template = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_TEMPLATE);
-		$result_key = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_RESULT_KEY);
-		$result_line_hint = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_LINE_HINT);
-		$result_line_before_hint = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_LINE_BEFORE_HINT);
-		$result_line_after_hint = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_LINE_AFTER_HINT);
-		$result_before_string = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_RESULT_BEFORE_STRING);
-		$result_divide_by = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_DIVIDE_BY);
-		$result_multiply_by = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_MULTIPLY_BY);
-		$strip_from_result = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_STRIP_FROM_RESULT);
-		$strip_result_postfix = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_STRIP_RESULT_POSTFIX);
-		$multi_match = $results_parser_xml->getXMLArrayValues(P_RESULTS_PARSER_MULTI_MATCH);
+		$results_parser_xml = new pts_parse_results_nye_XmlReader($parse_xml_file);
+		$result_match_test_arguments = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/MatchToTestArguments');
+		$result_template = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/OutputTemplate');
+		$result_key = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/ResultKey');
+		$result_line_hint = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/LineHint');
+		$result_line_before_hint = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/LineBeforeHint');
+		$result_line_after_hint = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/LineAfterHint');
+		$result_before_string = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/ResultBeforeString');
+		$result_divide_by = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/DivideResultBy');
+		$result_multiply_by = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/MultiplyResultBy');
+		$strip_from_result = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/StripFromResult');
+		$strip_result_postfix = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/StripResultPostfix');
+		$multi_match = $results_parser_xml->getXMLArrayValues('PhoronixTestSuite/ResultsParser/MultiMatch');
 		$test_result = false;
 
 		for($i = 0; $i < count($result_template); $i++)
@@ -400,17 +419,17 @@ class pts_test_result_parser
 
 			if($result_key[$i] == null)
 			{
-				$result_key[$i] = "#_RESULT_#";
+				$result_key[$i] = '#_RESULT_#';
 			}
 			else
 			{
 				switch($result_key[$i])
 				{
-					case "PTS_TEST_ARGUMENTS":
-						$result_key[$i] = "#_" . str_replace(' ', '', $pts_test_arguments) . "_#";
+					case 'PTS_TEST_ARGUMENTS':
+						$result_key[$i] = '#_' . str_replace(' ', '', $pts_test_arguments) . '_#';
 						break;
-					case "PTS_USER_SET_ARGUMENTS":
-						$result_key[$i] = "#_" . str_replace(' ', '', $extra_arguments) . "_#";
+					case 'PTS_USER_SET_ARGUMENTS':
+						$result_key[$i] = '#_' . str_replace(' ', '', $extra_arguments) . '_#';
 						break;
 				}
 			}
@@ -493,7 +512,7 @@ class pts_test_result_parser
 
 			if($search_key != null || $result_line_before_hint[$i] != null || $result_line_after_hint[$i] != null || $result_template_r[0] == $result_key[$i])
 			{
-				$is_multi_match = !empty($multi_match[$i]) && $multi_match[$i] != "NONE";
+				$is_multi_match = !empty($multi_match[$i]) && $multi_match[$i] != 'NONE';
 
 				do
 				{
@@ -501,21 +520,21 @@ class pts_test_result_parser
 
 					if($result_line_before_hint[$i] != null)
 					{
-						pts_test_profile_debug_message("Result Parsing Line Before Hint: " . $result_line_before_hint[$i]);
+						pts_client::test_profile_debug_message('Result Parsing Line Before Hint: ' . $result_line_before_hint[$i]);
 						$result_line = substr($result_output, strpos($result_output, "\n", strrpos($result_output, $result_line_before_hint[$i])));
 						$result_line = substr($result_line, 0, strpos($result_line, "\n", 1));
 						$result_output = substr($result_output, 0, strrpos($result_output, "\n", strrpos($result_output, $result_line_before_hint[$i]))) . "\n";
 					}
 					else if($result_line_after_hint[$i] != null)
 					{
-						pts_test_profile_debug_message("Result Parsing Line After Hint: " . $result_line_after_hint[$i]);
+						pts_client::test_profile_debug_message('Result Parsing Line After Hint: ' . $result_line_after_hint[$i]);
 						$result_line = substr($result_output, 0, strrpos($result_output, "\n", strrpos($result_output, $result_line_before_hint[$i])));
 						$result_line = substr($result_line, strrpos($result_line, "\n", 1) + 1);
 						$result_output = null;
 					}
 					else if($search_key != null)
 					{
-						pts_test_profile_debug_message("Result Parsing Search Key: " . $search_key);
+						pts_client::test_profile_debug_message('Result Parsing Search Key: ' . $search_key);
 						$result_line = substr($result_output, 0, strpos($result_output, "\n", strrpos($result_output, $search_key)));
 						$start_of_line = strrpos($result_line, "\n");
 						$result_output = substr($result_line, 0, $start_of_line) . "\n";
@@ -524,11 +543,11 @@ class pts_test_result_parser
 					else
 					{
 						// Condition $result_template_r[0] == $result_key[$i], include entire file since there is nothing to search
-						pts_test_profile_debug_message("No Result Parsing Hint, Including Entire Result Output");
+						pts_client::test_profile_debug_message('No Result Parsing Hint, Including Entire Result Output');
 						$result_line = trim($result_output);
 					}
 
-					pts_test_profile_debug_message("Result Line: " . $result_line);
+					pts_client::test_profile_debug_message('Result Line: ' . $result_line);
 
 					$result_r = explode(' ', pts_strings::trim_spaces(str_replace(array('(', ')', "\t"), ' ', str_replace('=', ' = ', $result_line))));
 					$result_r_pos = array_search($result_key[$i], $result_r);
@@ -586,10 +605,10 @@ class pts_test_result_parser
 
 			switch($multi_match[$i])
 			{
-				case "REPORT_ALL":
+				case 'REPORT_ALL':
 					$test_result = implode(',', $test_results);
 					break;
-				case "AVERAGE":
+				case 'AVERAGE':
 				default:
 					$test_result = array_sum($test_results) / count($test_results);
 					break;
