@@ -3,8 +3,8 @@
 /*
 	Phoronix Test Suite
 	URLs: http://www.phoronix.com, http://www.phoronix-test-suite.com/
-	Copyright (C) 2008 - 2010, Phoronix Media
-	Copyright (C) 2008 - 2010, Michael Larabel
+	Copyright (C) 2008 - 2011, Phoronix Media
+	Copyright (C) 2008 - 2011, Michael Larabel
 
 	This program is free software; you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@ class pts_user_io
 	{
 		do
 		{
-			echo "\n" . $question . ": ";
+			echo PHP_EOL . $question . ': ';
 			$answer = pts_user_io::read_user_input();
 		}
 		while(!$allow_null && empty($answer));
@@ -41,44 +41,35 @@ class pts_user_io
 	{
 		if(!empty($message))
 		{
-			echo $message . "\n";
+			echo $message . PHP_EOL;
 
-			if(pts_read_assignment("IS_BATCH_MODE") == false && pts_read_assignment("AUTOMATED_MODE") == false)
+			if((pts_c::$test_flags ^ pts_c::batch_mode) && (pts_c::$test_flags ^ pts_c::auto_mode))
 			{
-				echo "\nHit Any Key To Continue...\n";
+				echo PHP_EOL . 'Hit Any Key To Continue...' . PHP_EOL;
 				pts_user_io::read_user_input();
 			}
 		}
 	}
-	public static function display_text_list($list_items, $line_start = "- ")
+	public static function display_text_list($list_items, $line_start = '- ')
 	{
 		$list = null;
 
 		foreach($list_items as &$item)
 		{
-			$list .= $line_start . $item . "\n";
+			$list .= $line_start . $item . PHP_EOL;
 		}
 
 		return $list;
 	}
-	public static function prompt_bool_input($question, $default = true, $question_id = "UNKNOWN")
+	public static function prompt_bool_input($question, $default = true, $question_id = 'UNKNOWN')
 	{
 		// Prompt user for yes/no question
-		if(pts_read_assignment("IS_BATCH_MODE"))
+		if((pts_c::$test_flags & pts_c::batch_mode))
 		{
 			switch($question_id)
 			{
-				case "SAVE_RESULTS":
-					$auto_answer = pts_config::read_user_config(P_OPTION_BATCH_SAVERESULTS, "TRUE");
-					break;
-				case "OPEN_BROWSER":
-					$auto_answer = pts_config::read_user_config(P_OPTION_BATCH_LAUNCHBROWSER, "FALSE");
-					break;
-				case "UPLOAD_RESULTS":
-					$auto_answer = pts_config::read_user_config(P_OPTION_BATCH_UPLOADRESULTS, "TRUE");
-					break;
 				default:
-					$auto_answer = "true";
+					$auto_answer = 'true';
 					break;
 			}
 
@@ -86,21 +77,21 @@ class pts_user_io
 		}
 		else
 		{
-			$question .= " (" . ($default == true ? "Y/n" : "y/N") . "): ";
+			$question .= ' (' . ($default == true ? 'Y/n' : 'y/N') . '): ';
 
 			do
 			{
 				pts_client::$display->generic_prompt($question);
 				$input = strtolower(pts_user_io::read_user_input());
 			}
-			while($input != "y" && $input != "n" && $input != "");
+			while($input != 'y' && $input != 'n' && $input != '');
 
 			switch($input)
 			{
-				case "y":
+				case 'y':
 					$answer = true;
 					break;
-				case "n":
+				case 'n':
 					$answer = false;
 					break;
 				default:
@@ -117,45 +108,46 @@ class pts_user_io
 
 		if($option_count == 1)
 		{
-			return $return_index ? 0 : array_pop($options_r);
+			return $return_index ? array_pop(array_keys($options_r)) : array_pop($options_r);
 		}
 
+		$select = array();
+
 		do
 		{
-			echo "\n";
-			for($i = 0; $i < $option_count; $i++)
+			echo PHP_EOL;
+			$key_index = array();
+			foreach(array_keys($options_r) as $i => $key)
 			{
-				echo ($i + 1) . ": " . str_repeat(' ', strlen($option_count) - strlen(($i + 1))) . $options_r[$i] . "\n";
+				$key_index[($i + 1)] = $key;
+				echo ($i + 1) . ': ' . str_repeat(' ', strlen($option_count) - strlen(($i + 1))) . $options_r[$key] . PHP_EOL;
 			}
-			echo "\n" . $user_string . ": ";
+			echo PHP_EOL . $user_string . ': ';
 			$select_choice = pts_user_io::read_user_input();
 
-			// Validate possible multi-select
-			$multi_choice = pts_strings::comma_explode($select_choice);
-			$multi_select_pass = false;
-
-			if($allow_multi_select && count($multi_choice) > 1)
+			foreach(($allow_multi_select ? pts_strings::comma_explode($select_choice) : array($select_choice)) as $choice)
 			{
-				$multi_select = array();
-				foreach($multi_choice as $choice)
+				if(in_array($choice, $options_r))
 				{
-					if(in_array($choice, $options_r) || isset($options_r[($choice - 1)]) && ($return_index || $choice = $options_r[($choice - 1)]) != null)
-					{
-						array_push($multi_select, $choice);
-					}
+					array_push($select, array_search($choice, $options_r));
 				}
-
-				if(count($multi_select) > 0)
+				else if(isset($key_index[$choice]))
 				{
-					$multi_select_pass = true;
-					$select_choice = implode(",", $multi_select);
-				
+					array_push($select, $key_index[$choice]);
 				}
 			}
 		}
-		while(!$multi_select_pass && !(in_array($select_choice, $options_r) || isset($options_r[($select_choice - 1)]) && ($return_index || $select_choice = $options_r[($select_choice - 1)]) != null));
+		while(!isset($select[0]));
 
-		return $select_choice;
+		if($return_index == false)
+		{
+			foreach($select as &$index)
+			{
+				$index = $options_r[$index];
+			}
+		}
+
+		return implode(',', $select);
 	}
 }
 
